#------------------------------------------------------------------------------
# build_naph_pbtk_pde.R
#
# Author: Dustin Kapraun, US EPA, November 2019
#
# This script translates the napthalene PBTK model defined in the MCSim model
# file "naph_pbtk_pde.model" to create a C file called "naph_pbtk_pde_model.c".
# It then compiles the C file to create a DLL file  called "naph_pbtk_pde.dll"
# (for Windows) or an SO file "naph_pbtk_pde.so" (for UNIX). The script also
# loads all functions defined in the file "RMCSim.R".
#
# WARNING: Running this script will delete any files that were created during a
# previous build.
#------------------------------------------------------------------------------

# Set working directory to the directory containing this file.
script_dir = dirname(sys.frame(1)$ofile)
setwd(script_dir)

# Load essential functions for working with MCSim models.
source("RMCSim.R")

# Specify the model name.
model_name = "naph_pbtk_pde"

# Remove files previously created through translation of the model file and
# compilation of the C file.
endings = c("_model.c", "_model.o", "_model.dll", "_model.so",
            "_model_inits.R")
files = list.files()
for (e in endings) {
    file_name = paste(model_name, e, sep="")
    if (file_name %in% files) {
        file.remove(file_name)
    }
}

# Build the model.
compile_model(model_name)